@@ -19,7 +19,7 @@
 
 import json
 from abc import abstractmethod
-from typing import Any, Dict, List, Optional, Union, cast
+from typing import Any, Dict, Iterable, List, Optional, Union
 
 from ..exception.output import FormatNotSupportedException
 from ..model.bom import Bom
@@ -56,28 +56,43 @@ class Json(BaseOutput, BaseSchemaVersion):
         if self.generated and not force_regeneration:
             return
 
+        bom = self.get_bom()
+        bom.validate()
+
         schema_uri: Optional[str] = self._get_schema_uri()
         if not schema_uri:
             raise FormatNotSupportedException(
-                f'JSON is not supported by CycloneDX in schema version {self.schema_version.to_version()}'
-            )
+                f'JSON is not supported by CycloneDX in schema version {self.schema_version.to_version()}')
 
-        vulnerabilities: Dict[str, List[Dict[Any, Any]]] = {"vulnerabilities": []}
-        if self.get_bom().components:
-            for component in cast(List[Component], self.get_bom().components):
-                for vulnerability in component.get_vulnerabilities():
-                    vulnerabilities['vulnerabilities'].append(
-                        json.loads(json.dumps(vulnerability, cls=CycloneDxJSONEncoder))
-                    )
+        extras = {}
+        if self.bom_supports_dependencies():
+            dep_components: Iterable[Component] = bom.components
+            if bom.metadata.component:
+                dep_components = [bom.metadata.component, *dep_components]
+            dependencies = []
+            for component in dep_components:
+                dependencies.append({
+                    'ref': str(component.bom_ref),
+                    'dependsOn': [*map(str, component.dependencies)]
+                })
+            if dependencies:
+                extras["dependencies"] = dependencies
+            del dep_components
 
-        bom_json = json.loads(json.dumps(self.get_bom(), cls=CycloneDxJSONEncoder))
+        if self.bom_supports_vulnerabilities():
+            vulnerabilities: List[Dict[Any, Any]] = []
+            if bom.components:
+                for component in bom.components:
+                    for vulnerability in component.get_vulnerabilities():
+                        vulnerabilities.append(
+                            json.loads(json.dumps(vulnerability, cls=CycloneDxJSONEncoder))
+                        )
+            if vulnerabilities:
+                extras["vulnerabilities"] = vulnerabilities
+
+        bom_json = json.loads(json.dumps(bom, cls=CycloneDxJSONEncoder))
         bom_json = json.loads(self._specialise_output_for_schema_version(bom_json=bom_json))
-        if self.bom_supports_vulnerabilities() and vulnerabilities['vulnerabilities']:
-            self._json_output = json.dumps(
-                {**self._create_bom_element(), **bom_json, **vulnerabilities}
-            )
-        else:
-            self._json_output = json.dumps({**self._create_bom_element(), **bom_json})
+        self._json_output = json.dumps({**self._create_bom_element(), **bom_json, **extras})
 
         self.generated = True
 
@@ -210,13 +225,13 @@ class JsonV1Dot1(Json, SchemaVersion1Dot1):
 class JsonV1Dot2(Json, SchemaVersion1Dot2):
 
     def _get_schema_uri(self) -> Optional[str]:
-        return 'http://cyclonedx.org/schema/bom-1.2a.schema.json'
+        return 'http://cyclonedx.org/schema/bom-1.2b.schema.json'
 
 
 class JsonV1Dot3(Json, SchemaVersion1Dot3):
 
     def _get_schema_uri(self) -> Optional[str]:
-        return 'http://cyclonedx.org/schema/bom-1.3.schema.json'
+        return 'http://cyclonedx.org/schema/bom-1.3a.schema.json'
 
 
 class JsonV1Dot4(Json, SchemaVersion1Dot4):
